@@ -154,6 +154,7 @@ class NumerousBaseJob:
             self.logger.error(f"An error occurred {tb_str(e)}")
             exit_code = ExitCode.ERROR
         finally:
+            self.logger.info(f"job ended with status {exit_code}")
             self._exit_code = exit_code
             self._save_states(self._t, exit_code.description, self._details)
             self.post_run(exit_code)
@@ -358,6 +359,6 @@ class NumerousSimulationJob(NumerousBaseJob):
             details = {"error message": tb_str(e), "previous_data": last_data, "data at crash": data}
             exit_code = ExitCode.ERROR
         finally:
-            self.logger.warning('job terminated')
+            self.logger.info('job terminated')
             self._details = details
             return exit_code
\ No newline at end of file
